<?php

namespace Tests\Feature;

use App\Models\Measure;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Tests\TestCase;

class MeasuresControllerTest extends TestCase
{
    use RefreshDatabase;

    /**
     * Test get all.
     *
     * @return void
     */
    public function testAdminCanGetAll()
    {
        $user = User::where('role', User::ROLE_ADMIN)->first();
        $response = $this->actingAs($user)->getJson(route('api.measures.all'));

        if ($response->exception) {
            dump($response->exception);
        }

        $response->assertOk();

        $m = Measure::all();

        $this->assertEquals($m->toArray(), $response->json());
    }

    /**
     * Test get all.
     *
     * @return void
     */
    public function testUserCanGetAll()
    {
        $user = User::where('role', '>', User::ROLE_ADMIN)->first();
        $response = $this->actingAs($user)->getJson(route('api.measures.all'));

        if ($response->exception) {
            dump($response->exception);
        }

        $response->assertOk();

        $m = Measure::all();

        $this->assertEquals($m->toArray(), $response->json());
    }

    /**
     * Test update.
     *
     * @return void
     */
    public function testAdminCanUpdateMeasure()
    {
        $user = User::where('role', User::ROLE_ADMIN)->first();

        $m = Measure::first()->toArray();

        $response = $this->actingAs($user)->putJson(route('api.measures.put', ['id' => $m['id'],
            $m['name'] = 'NAME',
            $m['short_name'] = 'SHORT_NAME',
            $m['efficiency'] = 'EFFICIENCY',
            $m['level1_title'] = 'LEVEL 1 TITLE',
            $m['level2_title'] = 'LEVEL 2 TITLE',
            $m['level3_title'] = 'LEVEL 3 TITLE', ]));

        if ($response->exception) {
            dump($response->exception);
        }

        $response->assertOk();

        $data = $response->json();

        $m = Measure::find($m['id']);

        $this->assertEquals($m->toArray(), $data);
        $this->assertEquals('LEVEL 1 TITLE', $data['level1_title']);
        $this->assertEquals('LEVEL 1 TITLE', $m->level1_title);
    }

    /*
     * Test update.
     *
     * @return void
     */

    public function testNonAdminCannotUpdateMeasure()
    {
        $user = User::where('role', User::ROLE_MANAGER)->first();

        $m = Measure::first()->toArray();

        $response = $this->actingAs($user)->putJson(route('api.measures.put', ['id' => $m['id'],
            $m['name'] = 'NAME',
            $m['short_name'] = 'SHORT_NAME',
            $m['efficiency'] = 'EFFICIENCY',
            $m['level1_title'] = 'LEVEL 1 TITLE',
            $m['level2_title'] = 'LEVEL 2 TITLE',
            $m['level3_title'] = 'LEVEL 3 TITLE', ]));

        $response->assertStatus(403);
    }

}
